@@ -8,7 +8,7 @@ use POE::Component::Pluggable::Constants qw(:ALL);
 use Socket;
 use vars qw($VERSION);
 
-$VERSION = '0.06';
+$VERSION = '0.08';
 
 sub spawn {
   my $package = shift;
@@ -335,7 +335,7 @@ sub POP3D_connection {
   return PLUGIN_EAT_NONE;
 }
 
-1;
+'poppet';
 __END__
 
 =head1 NAME
@@ -477,7 +477,7 @@ One may either interface with the component via the POE API or via L<POE::Compon
 
 =over
 
-=item spawn
+=item C<spawn>
 
 Takes a number of optional arguments:
 
@@ -498,27 +498,27 @@ Returns a POE::Component::Server::POP3 object.
 
 =over
 
-=item session_id
+=item C<session_id>
 
 Returns the POE::Session ID of the component.
 
-=item shutdown
+=item C<shutdown>
 
 Terminates the component. Shuts down the listener and disconnects connected clients.
 
-=item send_event
+=item C<send_event>
 
 Sends an event through the component's event handling system.
 
-=item send_to_client
+=item C<send_to_client>
 
 Send some output to a connected client. First parameter must be a valid client id. Second parameter is a string of text to send.
 
-=item disconnect
+=item C<disconnect>
 
 Places a client connection in pending disconnect state. Requires a valid client ID as a parameter. Set this, then send an applicable message to the client using send_to_client() and the client connection will be terminated.
 
-=item getsockname
+=item C<getsockname>
 
 Access to the L<POE::Wheel::SocketFactory> method of the underlying listening socket.
 
@@ -530,31 +530,31 @@ These are events that the component will accept:
 
 =over
 
-=item register
+=item C<register>
 
 Takes N arguments: a list of event names that your session wants to listen for, minus the 'pop3d_' prefix, ( this is 
 similar to L<POE::Component::IRC> ). 
 
-Registering for 'all' will cause it to send all POP3D-related events to you; this is the easiest way to handle it.
+Registering for C<all> will cause it to send all POP3D-related events to you; this is the easiest way to handle it.
 
-=item unregister
+=item C<unregister>
 
 Takes N arguments: a list of event names which you don't want to receive. If you've previously done a 'register' for a particular event which you no longer care about, this event will tell the POP3D to stop sending them to you. (If you haven't, it just ignores you. No big deal).
 
-=item shutdown
+=item C<shutdown>
 
 Terminates the component. Shuts down the listener and disconnects connected clients.
 
-=item send_event
+=item C<send_event>
 
 Sends an event through the component's event handling system. 
 
-=item send_to_client
+=item C<send_to_client>
 
 Send some output to a connected client. First parameter must be a valid client ID. 
 Second parameter is a string of text to send.
 
-=item disconnect
+=item C<disconnect>
 
 Places a client connection in pending disconnect state. Requires a valid client ID as a parameter. Set this, then send an applicable message to the client using send_to_client() and the client connection will be terminated.
 
@@ -566,18 +566,18 @@ The component sends the following events to registered sessions:
 
 =over
 
-=item pop3d_registered
+=item C<pop3d_registered>
 
 This event is sent to a registering session. ARG0 is the POE::Component::Server::POP3
 object.
 
-=item pop3d_listener_failed
+=item C<pop3d_listener_failed>
 
 Generated if the component cannot either start a listener or there is a problem
 accepting client connections. ARG0 contains the name of the operation that failed. 
 ARG1 and ARG2 hold numeric and string values for $!, respectively.
 
-=item pop3d_connection
+=item C<pop3d_connection>
 
 Generated whenever a client connects to the component. ARG0 is the client ID, ARG1
 is the client's IP address, ARG2 is the client's TCP port. ARG3 is our IP address and
@@ -586,11 +586,11 @@ ARG4 is our socket port.
 If 'handle_connects' is true ( which is the default ), the component will automatically
 send an initial connection response to the client.
 
-=item pop3d_disconnected
+=item C<pop3d_disconnected>
 
 Generated whenever a client disconnects. ARG0 is the client ID.
 
-=item pop3d_cmd_*
+=item C<pop3d_cmd_*>
 
 Generated for each POP3 command that a connected client sends to us. ARG0 is the 
 client ID. ARG1 .. ARGn are any parameters that are sent with the command. Check 
@@ -609,12 +609,12 @@ There are two types of handlers that can registered for by plugins, these are
 
 =over
 
-=item POP3D
+=item C<POP3D>
 
 These are the 'pop3d_' prefixed events that are generated. In a handler arguments are
 passed as scalar refs so that you may mangle the values if required.
 
-=item POP3C
+=item C<POP3C>
 
 These are generated whenever a response is sent to a client. Again, any 
 arguments passed are scalar refs for manglement. There is really on one type
@@ -634,23 +634,23 @@ The return values have the following significance:
 
 =over 
 
-=item POP3D_EAT_NONE
+=item C<POP3D_EAT_NONE>
 
 This means the event will continue to be processed by remaining plugins and
 finally, sent to interested sessions that registered for it.
 
-=item POP3D_EAT_CLIENT
+=item C<POP3D_EAT_CLIENT>
 
 This means the event will continue to be processed by remaining plugins but
 it will not be sent to any sessions that registered for it. This means nothing
 will be sent out on the wire if it was an POP3C event, beware!
 
-=item POP3D_EAT_PLUGIN
+=item C<POP3D_EAT_PLUGIN>
 
 This means the event will not be processed by remaining plugins, it will go
 straight to interested sessions.
 
-=item POP3D_EAT_ALL
+=item C<POP3D_EAT_ALL>
 
 This means the event will be completely discarded, no plugin or session will see it. This
 means nothing will be sent out on the wire if it was an POP3C event, beware!
@@ -663,11 +663,11 @@ The following methods are available:
 
 =over
 
-=item pipeline
+=item C<pipeline>
 
 Returns the L<POE::Component::Pluggable::Pipeline> object.
 
-=item plugin_add
+=item C<plugin_add>
 
 Accepts two arguments:
 
@@ -684,7 +684,7 @@ This method goes through the pipeline's push() method.
 Returns the number of plugins now in the pipeline if plugin was initialized, undef
 if not.
 
-=item plugin_del
+=item C<plugin_del>
 
 Accepts one argument:
 
@@ -696,7 +696,7 @@ This method will call $plugin->plugin_unregister( $pop3d )
 
 Returns the plugin object if the plugin was removed, undef if not.
 
-=item plugin_get
+=item C<plugin_get>
 
 Accepts one argument:
 
@@ -706,21 +706,21 @@ This method goes through the pipeline's get() method.
 
 Returns the plugin object if it was found, undef if not.
 
-=item plugin_list
+=item C<plugin_list>
 
 Has no arguments.
 
 Returns a hashref of plugin objects, keyed on alias, or an empty list if there are no
 plugins loaded.
 
-=item plugin_order
+=item C<plugin_order>
 
 Has no arguments.
 
 Returns an arrayref of plugin objects, in the order which they are encountered in the
 pipeline.
 
-=item plugin_register
+=item C<plugin_register>
 
 Accepts the following arguments:
 
@@ -737,7 +737,7 @@ It is possible to register for all events by specifying 'all' as an event.
 
 Returns 1 if everything checked out fine, undef if something's seriously wrong
 
-=item plugin_unregister
+=item C<plugin_unregister>
 
 Accepts the following arguments:
 
@@ -809,7 +809,7 @@ Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
 
 =head1 LICENSE
 
-Copyright L<(c)> Chris Williams
+Copyright E<copy> Chris Williams
 
 This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
 
@@ -819,3 +819,4 @@ L<POE::Component::Pluggable>
 
 RFC 1939 L<http://www.faqs.org/rfcs/rfc1939.html>
 
+=cut
